import psutil

def processes():
    processes = []
    attrs = [
        'pid',
        'ppid',
        'name',
        'username',
        'memory_percent',
        'cpu_percent',
        'cpu_times',
        'num_threads',
        'status',
        'connections',
    ]

    for proc in psutil.process_iter():
        try:
            process = proc.as_dict(attrs=attrs)
            processes.append(process)
        except psutil.NoSuchProcess:
            pass
    return processes



import os
import platform
import psutil

def interfaces(operating_system):
    if operating_system == 'Linux':
        with os.popen('ls -l /sys/class/net/ | grep -v virtual | grep devices | rev | cut -d "/" -f1 | rev') as f:
            return f.read().strip().split('\n')
    elif operating_system == 'Darwin':
        with os.popen('scutil --nwi | grep "Network interfaces" | cut -d " " -f3') as f:
            return f.read().strip().split('\n')
    else:
        return []

def network():
    network = []
    network_interfaces = interfaces(platform.system())

    for k, v in psutil.net_io_counters(pernic=True).items():
        if k not in network_interfaces:
            continue
        network.append({ k: v._asdict() })

    return network



import psutil

IGNORED_DEVICES = ['/loop', '/snap']
IGNORED_FS = ['squashfs', 'cagefs-skeleton']

def partitions_metadata():
    partitions_metadata = []

    for part in psutil.disk_partitions(False):
        if part.device.startswith(tuple(IGNORED_DEVICES)):
            continue

        if part.fstype in IGNORED_FS:
            continue

        partitions_metadata.append({
            'device': part.device,
            'mountpoint': part.mountpoint,
            'fstype': part.fstype,
            'opts': part.opts,
        })

    return partitions_metadata

def partitions_usage():
    partitions_usage = {}

    for _, v in enumerate(psutil.disk_partitions(all=False)):
        if v.device.startswith(tuple(IGNORED_DEVICES)):
            continue

        if v.fstype in IGNORED_FS:
            continue

        partitions_usage[v.mountpoint] = psutil.disk_usage(v.mountpoint)._asdict()

    return partitions_usage
